# JuliaBridge
A Python package for communication with Julia.
---
一个用于与 Julia 进行通信的 Python 包。


# How to use
For detailed usage instructions, please visit the [GitHub Repository](https://github.com/barkure/JuliaBridge#readme).
---
有关详细使用说明，请访问 [GitHub 仓库](https://github.com/barkure/JuliaBridge#readme)。